@@ -1,5 +1,5 @@
 package Astro::ADS;
-$Astro::ADS::VERSION = '1.91';
+$Astro::ADS::VERSION = '1.92';
 use Moo;
 
 use Carp;
@@ -77,9 +77,13 @@ sub get_response {
 }
 
 sub post_response {
-    my ($self, $url, $hash) = @_;
+    my ($self, $url, $content) = @_;
 
-    my $tx = $self->ua->build_tx( POST => $url, json => $hash );
+    # this will work until we need to do form submission
+    # hashrefs are sent as JSON
+    my $tx = ref $content eq 'HASH'
+        ? $self->ua->build_tx( POST => $url, json => $content )
+        : $self->ua->build_tx( POST => $url, $content );
     $tx->req->headers->authorization( 'Bearer ' . $self->token );
     carp "Request sent to $url\n\n", $tx->req->to_string if $DEBUG;
    
@@ -88,7 +92,17 @@ sub post_response {
         carp "Got this error: ", $error;
     }
 
-    return $tx->result;
+    my $res;
+    try { $res = $tx->result } # call to result dies on connection error
+    catch ($error) {
+        carp "Connection error: ", $error;
+        return;
+    }
+    if    ($res->is_success)  { warn $res->body if $DEBUG > 1 }
+    elsif ($res->is_error)    { carp 'HTTP Error: ', $res->message }
+    elsif ($res->code == 301) { carp 'Redirected: ', $res->headers->location if $DEBUG }
+
+    return $res;
 }
 
 1; # Perl is my Igor
@@ -103,7 +117,7 @@ Astro::ADS - Perl library to connect with the Harvard Astrophysical Data Service
 
 =head1 VERSION
 
-version 1.91
+version 1.92
 
 =head1 SYNOPSIS
 
@@ -145,8 +159,11 @@ the publications found through this API. Please refer to the
 L<ADS Terms and Conditions of Use|http://adsabs.github.io/help/terms/>
 
 To acknowledge the ADS in a publication, refer to the text at the
-bottom of L<About ADS|https://ui.adsabs.harvard.edu/about/>.
-To acknowlegde use of this module, it will be sufficient to mention
+bottom of L<About ADS|https://ui.adsabs.harvard.edu/about/>, which suggests:
+I<“This research has made use of the Astrophysics Data System,
+funded by NASA under Cooperative Agreement 80NSSC21M0056.”>
+
+To acknowledge use of this module, it will be sufficient to mention
 I<Perl's Astro::ADS is available at https://metacpan.org/pod/Astro::ADS>
 
 =head1 COPYRIGHT AND LICENSE
